@@ -104,6 +104,26 @@ class Examples:
     with open(list_item13_filepath) as f:
         list_item13_json = json.load(f)
 
+    list_item14_filepath = RESOURCES_DIR / "list_item14.json"
+
+    with open(list_item14_filepath) as f:
+        list_item14_json = json.load(f)
+
+    list_item15_filepath = RESOURCES_DIR / "list_item15.json"
+
+    with open(list_item15_filepath) as f:
+        list_item15_json = json.load(f)
+
+    list_item16_filepath = RESOURCES_DIR / "list_item16.json"
+
+    with open(list_item16_filepath) as f:
+        list_item16_json = json.load(f)
+
+    list_item17_filepath = RESOURCES_DIR / "list_item17.json"
+
+    with open(list_item17_filepath) as f:
+        list_item17_json = json.load(f)
+
     described_by = (
         "https://raw.githubusercontent.com/AllenNeuralDynamics/"
         "aind-data-schema/main/src/aind_data_schema/procedures.py"
@@ -269,7 +289,7 @@ class Examples:
             injection_materials=None,
             injection_duration=4,
             recovery_time=None,
-            workstation_id="Select...",
+            workstation_id=None,
             instrument_id="Select...",
             injection_hemisphere=Side.LEFT,
             injection_coordinate_ml=-0.6,
@@ -315,7 +335,7 @@ class Examples:
             injection_materials=None,
             injection_duration=None,
             recovery_time=None,
-            workstation_id="Select...",
+            workstation_id=None,
             instrument_id="NJ#4",
             injection_hemisphere=Side.RIGHT,
             injection_coordinate_ml=-0.6,
@@ -466,47 +486,300 @@ class Examples:
 
     expected_procedures1 = Procedures.construct(
         describedBy=described_by,
-        schema_version="0.6.1",
+        schema_version="0.6.2",
         subject_id="650102",
         subject_procedures=expected_subject_procedures1,
     )
 
     expected_subject_procedures2 = [
+        # from list item 8
+        IontophoresisInjection.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            injection_coordinate_ml=-2.3,
+            injection_coordinate_ap=4.72,
+            injection_coordinate_depth=None,
+            injection_angle=0.0,
+            injection_hemisphere=Side.RIGHT,
+            procedure_type="Iontophoresis",
+            injection_current=5.0,
+            alternating_current="7/7",
+        ),
+        # from list item 9
         Headframe.construct(
             start_date=datetime.date(2022, 1, 3),
             end_date=datetime.date(2022, 1, 3),
             experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            procedure_type="Headframe",
+            headframe_type="Visual Ctx",
+            headframe_part_number="0160-100-10",
+            well_type="Mesoscope",
+            well_part_number="0160-200-20",
         ),
-        Headframe.construct(
-            start_date=datetime.date(2022, 1, 3),
-            end_date=datetime.date(2022, 1, 3),
-            experimenter_full_name="NSB-187",
-        ),
-        IontophoresisInjection.construct(
-            start_date=datetime.date(2022, 1, 3),
-            end_date=datetime.date(2022, 1, 3),
-            experimenter_full_name="NSB-187",
-        ),
-        IontophoresisInjection.construct(
-            start_date=datetime.date(2022, 1, 3),
-            end_date=datetime.date(2022, 1, 3),
-            experimenter_full_name="NSB-187",
-        ),
-        IontophoresisInjection.construct(
-            start_date=datetime.date(2022, 1, 3),
-            end_date=datetime.date(2022, 1, 3),
-            experimenter_full_name="NSB-187",
-        ),
+        # from list item 10
         Craniotomy.construct(
             start_date=datetime.date(2022, 1, 3),
             end_date=datetime.date(2022, 1, 3),
             experimenter_full_name="NSB-187",
+            iacuc_protocol=None,
+            animal_weight_prior=None,
+            animal_weight_post=None,
+            procedure_type="Craniotomy",
+            craniotomy_hemisphere=None,
+            craniotomy_coordinates_ml=None,
+            craniotomy_coordinates_ap=None,
+        ),
+        # from list item 11
+        Headframe.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            procedure_type="Headframe",
+            headframe_type="WHC NP",
+            headframe_part_number="0160-100-42",
+            well_type="Neuropixel",
+            well_part_number="0160-200-36",
+        ),
+        NanojectInjection.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            injection_coordinate_ml=3.0,
+            injection_coordinate_ap=-2.45,
+            injection_coordinate_depth=None,
+            injection_angle=None,
+            procedure_type="Nanoject (Pressure)",
+            injection_volume=500.0,
+        ),
+        NanojectInjection.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            injection_coordinate_ml=3.0,
+            injection_coordinate_ap=-2.45,
+            injection_coordinate_depth=None,
+            injection_angle=None,
+            procedure_type="Nanoject (Pressure)",
+            injection_volume=600.0,
+        ),
+        NanojectInjection.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            procedure_type="Nanoject (Pressure)",
+            injection_coordinate_ml=None,
+            injection_coordinate_ap=None,
+            injection_coordinate_depth=None,
+            injection_angle=None,
+            injection_volume=600.0,
+        ),
+        # from list item 14
+        Headframe.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            procedure_type="Headframe",
+            headframe_type="Frontal Ctx",
+            headframe_part_number="0160-100-46",
+            well_type="WHC NP",
+            well_part_number="0160-055-08",
+        ),
+        NanojectInjection.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            injection_coordinate_ml=-5.2,
+            injection_coordinate_ap=-0.85,
+            injection_coordinate_depth=-3.1,
+            injection_angle=0.0,
+            injection_hemisphere=Side.LEFT,
+            procedure_type="Nanoject (Pressure)",
+            injection_volume=600.0,
+            notes=None,
         ),
         FiberImplant.construct(
             start_date=datetime.date(2022, 1, 3),
             end_date=datetime.date(2022, 1, 3),
             experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            notes=None,
+            procedure_type="Fiber implant",
+            probes=OphysProbe.construct(
+                name="Probe A",
+                stereotactic_coordinate_ap=-0.85,
+                stereotactic_coordinate_ml=-5.2,
+                stereotactic_coordinate_dv=-2.95,
+                angle=0.0,
+            ),
         ),
+        IontophoresisInjection.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            notes=None,
+            procedure_type="Iontophoresis",
+            injection_hemisphere=Side.LEFT,
+            injection_coordinate_ml=-0.5,
+            injection_coordinate_ap=2.0,
+            injection_coordinate_depth=5.0,
+            injection_angle=0.0,
+            injection_current=None,
+            alternating_current="7/7",
+        ),
+        FiberImplant.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            notes=None,
+            procedure_type="Fiber implant",
+            probes=OphysProbe.construct(
+                name="Probe B",
+                stereotactic_coordinate_ap=2.0,
+                stereotactic_coordinate_ml=-0.5,
+                stereotactic_coordinate_dv=-1.05,
+                angle=0.0,
+            ),
+        ),
+        IontophoresisInjection.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            injection_coordinate_ml=-2.2,
+            injection_coordinate_ap=-6.1,
+            injection_coordinate_depth=3.1,
+            injection_angle=0.0,
+            injection_hemisphere=Side.LEFT,
+            procedure_type="Iontophoresis",
+            injection_current=5.0,
+            alternating_current="7/7",
+        ),
+        FiberImplant.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            procedure_type="Fiber implant",
+            probes=OphysProbe.construct(
+                name="Probe C",
+                stereotactic_coordinate_ap=-6.1,
+                stereotactic_coordinate_ml=-2.2,
+                stereotactic_coordinate_dv=-1.85,
+                angle=0.0,
+            ),
+        ),
+        IontophoresisInjection.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            injection_coordinate_ml=-2.5,
+            injection_coordinate_ap=1.0,
+            injection_coordinate_depth=3.0,
+            injection_angle=0.0,
+            injection_hemisphere=Side.RIGHT,
+            procedure_type="Iontophoresis",
+            injection_current=5.0,
+            alternating_current="7/7",
+        ),
+        FiberImplant.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            procedure_type="Fiber implant",
+            probes=OphysProbe.construct(
+                name="Probe D",
+                stereotactic_coordinate_ap=1.0,
+                stereotactic_coordinate_ml=-2.5,
+                stereotactic_coordinate_dv=-1.8,
+                angle=0.0,
+            ),
+        ),
+        # from list item 15
+        Headframe.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            procedure_type="Headframe",
+            headframe_type="Motor Ctx",
+            headframe_part_number="0160-100-51",
+            well_type="Scientifica (CAM)",
+            well_part_number="Rev A",
+        ),
+        # from list item 16
+        Headframe.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            procedure_type="Headframe",
+            headframe_type="AI Straight Bar",
+            headframe_part_number=None,
+            well_type="No Well",
+            well_part_number=None,
+        ),
+        # from list item 17
+        Headframe.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            procedure_type="Headframe",
+            headframe_type="WHC 2P",
+            headframe_part_number="0160-100-45",
+            well_type="WHC 2P",
+            well_part_number="0160-200-62",
+        ),
+        # from list item 13
         SubjectProcedure.construct(
             start_date=datetime.date(2022, 1, 3),
             end_date=datetime.date(2022, 1, 3),
@@ -612,6 +885,22 @@ class TestSharepointClient(unittest.TestCase):
         list_item13.get_property = lambda x: Examples.list_item13_json[x]
         list_item_collection_2023.add_child(list_item13)
 
+        list_item14 = ListItem(context=blank_ctx)
+        list_item14.get_property = lambda x: Examples.list_item14_json[x]
+        list_item_collection_2023.add_child(list_item14)
+
+        list_item15 = ListItem(context=blank_ctx)
+        list_item15.get_property = lambda x: Examples.list_item15_json[x]
+        list_item_collection_2023.add_child(list_item15)
+
+        list_item16 = ListItem(context=blank_ctx)
+        list_item16.get_property = lambda x: Examples.list_item16_json[x]
+        list_item_collection_2023.add_child(list_item16)
+
+        list_item17 = ListItem(context=blank_ctx)
+        list_item17.get_property = lambda x: Examples.list_item17_json[x]
+        list_item_collection_2023.add_child(list_item17)
+
         procedures2023 = self.client._map_response(
             version=version_2023,
             list_items=list_item_collection_2023,
@@ -619,6 +908,7 @@ class TestSharepointClient(unittest.TestCase):
         self.assertCountEqual(
             Examples.expected_subject_procedures1, procedures2019
         )
+
         self.assertCountEqual(
             Examples.expected_subject_procedures2, procedures2023
         )
